@@ -15,18 +15,18 @@ test_that(
       file.path(tempdir(), "MODIStsp/LAI_8Days_500m_v6"),
       pattern = "\\.tif$", recursive = TRUE, full.names = TRUE)
     file_sizes_dat <- file.info(out_files_dat)$size
-    expect_equal(file_sizes_dat, c(1633, 1611))
+    expect_equal(file_sizes_dat, c(1663, 1636))
     means <- unlist(
       lapply(out_files_dat,
              FUN = function(x) {
-               mean(raster::getValues(raster::raster(x)), na.rm = T)
+               mean(suppressWarnings(raster::getValues(raster::raster(x))), na.rm = T)
              })
     )
-    expect_equal(means, c(14.9886548, 14.9802337), tolerance = 0.001, scale = 1)
+    expect_equal(means, c(145.7023 , 145.6939), tolerance = 0.001, scale = 1)
     r <- raster::raster(out_files_dat[1])
     expect_equal(
       st_crs(r)$input,
-      "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"
+      "+proj=longlat +datum=WGS84 +no_defs"
     )
     expect_equal(raster::res(r), c(0.01, 0.01), tolerance = 0.001, scale = 1)
     # re-run with same parameterization. Since Reprocess = "No", the
@@ -37,6 +37,19 @@ test_that(
     MODIStsp(test = 6)
     tt <- Sys.time() - t1
     expect_true(tt < 5)
-    unlink(file_sizes_dat)
+    unlink(out_files_dat)
+
+    # re-run with same parameterization but nodata_chage to true to see
+    # that nodata_change is ok when scale_val is true and multiple nodata
+    context("MODIStsp Test 6: multiple nodata and nodata_change")
+    MODIStsp(test = "06a")
+    means <- unlist(
+      lapply(out_files_dat,
+             FUN = function(x) {
+               mean(raster::getValues(suppressWarnings(raster::raster(x))), na.rm = T)
+             })
+    )
+    expect_equal(means, c(1.086066 , 1.066393), tolerance = 0.001, scale = 1)
+    unlink(out_files_dat)
   }
 )
